/*
  OS Pixie MK1 Single Channel Transmitter Enclosure
  Drawn by Mike Kitchen 2018.03.11 (yy.mm.dd)
  Modified by Dave Jones 5-7-2022
  There are separate files for the lid and the on-off switch shroud
  The original switch 17.5mm mounting centres, that are not available. It has been replaced with a switch with 19mm centres.
  The pushbuttton uses common 6.35mm - 7mm bushed switches (original 9mm)
  The lid fixing pillare is larger than original as it now has M3 thread. There is no thread printed, manually tap the M3 thread
  The original hole for tuning has been deleted
  The "Made in Japan" has been omitted as the text is too fine to print
*/

$fn = 80; //Render a bit smoother.

  /*main case is constructed of three cubes, two in the shape of a cross
    the third is taller and is the shape of the intersection of the other two.
    the missing bits are filled in with cylinders to radius the side edges
    and on the top edges. The corners on the top are finished with
    spheres to round the top corners
    
    It is called twice. The first time it draws the main lid, then it is
    called a second time, this time smaller in width and length and 1.5mm shorter in height
    with "difference" so it hollow out the centre
  */
  
module enclosure(length, width, height, radius) {

  translate ([0, 0, -radius / 2]) {
    cube ([length, width - (2 * radius), height - radius], center = true);
    cube ([length - (2 * radius), width, height - radius], center = true);
  }
  cube ([length - (2 * radius), width - (2 * radius), height], center = true);

  //Radius the four short sides (vertical to the lid)
  translate ([length / 2 - radius, width / 2 - radius, -radius / 2]) {
    cylinder (r = radius, h = (height - radius), center = true);
  }
  translate ([length / 2 - radius, radius - (width / 2), -radius / 2]) {
    cylinder (r = radius, h = (height - radius), center = true);
  }
  translate ([radius - (length / 2), width / 2 - radius, -radius / 2]) {
    cylinder (r = radius, h = (height - radius), center = true);
  }
  translate ([radius - (length / 2), radius - (width / 2), -radius / 2]) {
    cylinder (r = radius, h = (height - radius), center = true);
  }
  //Radius the four long sides (parallel with the lid)
  rotate(a = [0, 90, 0]) {
    translate ([radius - (height / 2), width / 2 - radius, 0]) {
      cylinder (r = radius, h = (length - 2 * radius), center = true);
    }
  }
  rotate(a = [0, 90, 0]) {
    translate ([radius - (height / 2), radius - (width / 2), 0]) {
      cylinder (r = radius, h = (length - 2 * radius), center = true);
    }
  }
  rotate(a = [90, 0, 0]) {
    translate ([length / 2 - radius, (height / 2) - radius, 0]) {
      cylinder (r = radius, h = (width - 2 * radius), center = true);
    }
  }
  rotate(a = [90, 0, 0]) {
    translate ([radius - (length / 2), (height / 2) - radius, 0]) {
      cylinder (r = radius, h = (width - 2 * radius), center = true);
    }
  }

  //radius the corners with 4 spheres (only bottom, not lid face)
  translate([length / 2 - radius, (width / 2) - radius, (height / 2) - radius]) {
    sphere(r = 3);
  }
  translate([radius - (length / 2), (width / 2) - radius, (height / 2) - radius]) {
    sphere(r = 3);
  }
  translate([length / 2 - radius, radius - (width / 2), (height / 2) - radius]) {
    sphere(r = 3);
  }
  translate([radius - (length / 2), radius - (width / 2), (height / 2) - radius]) {
    sphere(r = 3);
  }
}
//End of module enclosure()

difference() { //To draw the enclosure then hollow it out and then remove other bits

  union() { //All the bits to add
    //Main case dimensions
    l1 = 92;
    w1 = 58;
    h1 = 24;
    r1 = 3;

    enclosure(l1, w1, h1, r1); //Length=92, width=58, height=24, corner radius=3

    //Add the two "grip" mouldings on the opposite side to the switches
    translate ([-30.5, w1 / 2 + 0.25, 8 - h1 / 2]) {
      cube ([1, 0.5, 16], center = true);
    }

    translate ([4 - 30.5, w1 / 2 + 0.25, 8 - h1 / 2]) {
      cube ([1, 0.5, 16], center = true);
    }

    //Add the five mouldings to the top of the enclosure (away from the lid)

    translate ([-34.5, 0, h1 / 2 + 0.25]) {
      cube ([1, w1 - 7, 0.5], center = true);
    }
    translate ([-30.5, 0, h1 / 2 + 0.25]) {
      cube ([1, w1 - 7, 0.5], center = true);
    }
    translate ([-26.5, 0, h1 / 2 + 0.25]) {
      cube ([1, w1 - 7, 0.5], center = true);
    }
    translate ([3.25 - 22.5, 0, h1 / 2 + 0.25]) {
      cube ([7.5, w1 - 7, 0.5], center = true);
    }
    translate ([l1 / 2 - 8, 0, h1 / 2 + 0.25]) {
      cube ([1, w1 - 7, 0.5], center = true);
    }
    
    //Add the "radius" to the 5 mouldings on the top (r=3.5mm)
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, -34.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, -30.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, -26.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, 3.25 - 22.5]) {
        cylinder (r = r1 + 0.5, h = 7.5, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, l1 / 2 - 8]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }

    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, -34.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, -30.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, -26.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, 3.25 - 22.5]) {
        cylinder (r = r1 + 0.5, h = 7.5, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, l1 / 2 - 8]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
  } //End of adding main enclosue

  //Remove the following bits

  //Remove the centre of the enclosure to give a wall thickness of 1.5mm
  //length and width 3mm less (3x3mm) and height 1.5mm less

  l2 = 92 - 3;
  w2 = 58 - 3;
  h2 = 24 - 1.6;
  r2 = 3;

  translate ([0, 0, -1.1]) { //remove the centre
    enclosure(l2, w2, h2, r2);
  }

  //On-Off Switch
  translate ([-6, -28, -3]) {
    rotate(a = [90, 0, 0]) {
      union() {

        //The switch leaver cut-out
        cube ([9, 4, 2.2], center = true);

        //The switch mounting hole cut-outs
        translate ([9.5, 0, 0]) {
          cylinder (d = 2.5, h = 2.2, center = true);
        }
        translate ([-9.5, 0, 0]) {
          cylinder (d = 2.5, h = 2.2, center = true);
        }
      }
    }
  }
  
  //Pushbutton Switch
  translate ([-31, -28, -3]) {
    rotate(a = [90, 0, 0]) {
      cylinder (d = 7, h = 2.2, center = true);
    }
  }
  
  //2.4 Antenna cut-out. Not to scale, but hopefully further enough from the edge so sma fit OK

  translate ([-45, 20, 3]) {
    rotate(a = [0, 90, 0]) {
      cylinder (d = 6.3, h = 3, center = true);
    }
  }
  
}

/*
    Next add the other bits and pieces. Do as a difference so can add bits and take bits away
    The screw fixing pillar and FrSky bind board stand-off to be added
    The 2.5mm hole to be taped M3 thread
*/

difference() { //Add bits to the enclosure

  union() { //Bits to add

    translate ([4.5, 8, 0]) { // 6mm Fixing pillar
      cylinder (d = 6, h = 24, center = true);
    }
    translate ([4.5, 8, 6.7]) { //Strengthening fillet (cone)
      cylinder (5,2.5,5);
    }
    //Battery compartment divider
    translate ([25,-28,-9]) cube([1.5,50,20]);
  }

  //Bits to remove
  //Hole for lid fixing screw into the fixing pillar
  translate ([4.5, 8, -4]) { 
    cylinder (d = 2.5, h = 18, center = true); //2.5mm hole (manually tap M3)
  }
  
}
