/*
  OS Pixie MK1 Single Channel Transmitter Lid
  Original drawn by Mike Kitchen 2018.03.11 (yy.mm.dd)
  Modified by Dave Jones 5-7-2022
*/

$fn = 80; //Render a bit smoother.

  /*main case is constructed of three cubes, two in the shape of a cross
    the third is taller and is the shape of the intersection of the other two.
    the missing bits are filled in with cylinders to radius the side edges
    and on the top edges. The corners on the top are finished with
    spheres to round the top corners
    
    It is called twice. The first time it draws the main lid, then it is
    called a second time, this time smaller in width and length and 1mm shorter in height
    with "difference" so it hollow out the centre
  */
 
module Pixie(){
union(){
    
    translate ([-13,-2.7,0])linear_extrude(5)
        text("P", size=5.5, font="Arial Black"); 
    
    translate ([-6.5,-2.7,0])linear_extrude(5)
        text("I", size=5.5, font="Arial Black"); 
    
    translate ([-2.5,-2.7,0])linear_extrude(5)
        text("X", size=5.5, font="Arial Black");
    
    translate ([4.3,-2.7,0])linear_extrude(5)
        text("I", size=5.5, font="Arial Black"); 
    
    translate ([8,-2.7,0])linear_extrude(5)
        text("E", size=5.5, font="Arial Black"); 
    
        hull(){ //Triangle
        translate([-22.5,0,0])cylinder(5,.1,.1); 
        translate([-15.5,2.25,0])cylinder(5,.1,.1);
        translate([-15.5,-2.25,0])cylinder(5,.1,.1);
    }
 hull(){ //Triangle
        translate([22,0,0])cylinder(5,.1,.1);
        translate([15.5,2.25,0])cylinder(5,.1,.1);
        translate([15.5,-2.25,0])cylinder(5,.1,.1);
    }
}
} 
module enclosure(length, width, height, radius) {

  translate ([0, 0, -radius / 2]) {
    cube ([length, width - (2 * radius), height - radius], center = true);
    cube ([length - (2 * radius), width, height - radius], center = true);
  }
  cube ([length - (2 * radius), width - (2 * radius), height], center = true);

  //Radius the four short sides (vertical to the lid)
  translate ([length / 2 - radius, width / 2 - radius, -radius / 2]) {
    cylinder (r = radius, h = (height - radius), center = true);
  }
  translate ([length / 2 - radius, radius - (width / 2), -radius / 2]) {
    cylinder (r = radius, h = (height - radius), center = true);
  }
  translate ([radius - (length / 2), width / 2 - radius, -radius / 2]) {
    cylinder (r = radius, h = (height - radius), center = true);
  }
  translate ([radius - (length / 2), radius - (width / 2), -radius / 2]) {
    cylinder (r = radius, h = (height - radius), center = true);
  }
  //Radius the four long sides (parallel with the lid)
  rotate(a = [0, 90, 0]) {
    translate ([radius - (height / 2), width / 2 - radius, 0]) {
      cylinder (r = radius, h = (length - 2 * radius), center = true);
    }
  }
  rotate(a = [0, 90, 0]) {
    translate ([radius - (height / 2), radius - (width / 2), 0]) {
      cylinder (r = radius, h = (length - 2 * radius), center = true);
    }
  }
  rotate(a = [90, 0, 0]) {
    translate ([length / 2 - radius, (height / 2) - radius, 0]) {
      cylinder (r = radius, h = (width - 2 * radius), center = true);
    }
  }
  rotate(a = [90, 0, 0]) {
    translate ([radius - (length / 2), (height / 2) - radius, 0]) {
      cylinder (r = radius, h = (width - 2 * radius), center = true);
    }
  }

  //radius the corners with 4 spheres (only bottom, not lid face)
  translate([length / 2 - radius, (width / 2) - radius, (height / 2) - radius]) {
    sphere(r = 3);
  }
  translate([radius - (length / 2), (width / 2) - radius, (height / 2) - radius]) {
    sphere(r = 3);
  }
  translate([length / 2 - radius, radius - (width / 2), (height / 2) - radius]) {
    sphere(r = 3);
  }
  translate([radius - (length / 2), radius - (width / 2), (height / 2) - radius]) {
    sphere(r = 3);
  }
}
//End of module enclosure()

difference() { //To draw the enclosure then hollow it out and then remove other bits

  union() { //All the bits to add
    //Main case dimensions
    l1 = 92;
    w1 = 58;
    h1 = 6.5;
    r1 = 3;

    enclosure(l1, w1, h1, r1); //Length=92, width=58, height=24, corner radius=3
      
    //Add Lip  
    hull(){ //Lip
        translate([41.5,24.5,-4.2])cylinder(5,3,3); 
        translate([41.5,-24.5,-4.2])cylinder(5,3,3);
        translate([-41.5,24.5,-4.2])cylinder(5,3,3);
        translate([-41.5,-24.5,-4.2])cylinder(5,3,3);
    }

    //Add the five mouldings to the top of the enclosure (away from the lid)

    translate ([-34.5, 0, h1 / 2 + 0.25]) {
      cube ([1, w1 - 7, 0.5], center = true);
    }
    translate ([-30.5, 0, h1 / 2 + 0.25]) {
      cube ([1, w1 - 7, 0.5], center = true);
    }
    translate ([-26.5, 0, h1 / 2 + 0.25]) {
      cube ([1, w1 - 7, 0.5], center = true);
    }
    translate ([3.25 - 22.5, 0, h1 / 2 + 0.25]) {
      cube ([7.5, w1 - 7, 0.5], center = true);
    }
    translate ([l1 / 2 - 8, 0, h1 / 2 + 0.25]) {
      cube ([1, w1 - 7, 0.5], center = true);
    }
    
    //Add the "radius" to the 5 mouldings on the top (r=3.5mm)
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, -34.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, -30.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, -26.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, 3.25 - 22.5]) {
        cylinder (r = r1 + 0.5, h = 7.5, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), w1 / 2 - 3.5, l1 / 2 - 8]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }

    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, -34.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, -30.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, -26.5]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, 3.25 - 22.5]) {
        cylinder (r = r1 + 0.5, h = 7.5, center = true);
      }
    }
    rotate(a = [0, 90, 0]) {
      translate ([3 - (h1 / 2), 3.5 - w1 / 2, l1 / 2 - 8]) {
        cylinder (r = r1 + 0.5, h = 1, center = true);
      }
    }
   
    
  } //End of adding main enclosue

  //Remove the following bits

  //Remove the centre of the enclosure to give a wall thickness of 3mm
  //length and width 6mm less (3x3mm) and height 2mm less

  l2 = 92 - 6;
  w2 = 58 - 6;
  h2 = 8.5;
  r2 = 3;

  translate ([0, 0, -2.5]) { //Remove the centre
    enclosure(l2, w2, h2, r2);
  }
  translate ([4.5,-8,0]) { 
    cylinder (d = 6, h = 14); //Hole for mounting screw
  }
  //Text and triangles
  translate([-19.3,0,3.2])rotate([0,0,90])Pixie();
  
  //Indent for OS sticker
  translate([30,14,2.6]) cylinder(d=19.75, h=2);
  
}
