/*
    Switch shroud for an OS Pixie MK1 and MK2.
    Drawn by Mike Kitchen 2018.03.11 (yy.mm.dd)
    Modified by Dave Jones 5/7/2022 (dd/mm/yyyy)
    19mm mounting centres (the original had 17.5mm, but no longer available)

*/

$fn = 80;
difference() { // Do a difference so can add bits then take bits away

 union(){ //First the bits to add
     
    cube ([20,10,1],center=true); //main body
     
    translate ([0,4,2]) { //switch shroud (one side)
     cube ([8,2,4.5],center=true);
    }
    translate ([0,-4,2]) { //switch shroud (other side)
     cube ([8,2,4.5],center=true);
    }
    
    //Switch shroud lower part so can add radius
    translate ([0,4,1]) { //switch shroud (one side)
     cube ([12,2,2.5],center=true);
    }
    translate ([0,-4,1]) { //switch shroud (other side)
     cube ([12,2,2.5],center=true);
    }

    //Radius to the switch shroud
    rotate(a=[90,0,0]) {
     translate ([4,2.25,4]) { //One end
      cylinder (d=4,h=2,center=true);
     }
    }
    rotate(a=[90,0,0]) {
     translate ([4,2.25,-4]) { //One end
      cylinder (d=4,h=2,center=true);
     }
    }
    rotate(a=[90,0,0]) {
     translate ([-4,2.25,4]) { //One end
      cylinder (d=4,h=2,center=true);
     }
    }
    rotate(a=[90,0,0]) {
     translate ([-4,2.25,-4]) { //One end
      cylinder (d=4,h=2,center=true);
     }
    }

    //Main body circular ends
    translate ([10,0,0]) { //One end
     cylinder (d=10,h=1,center=true);
    }
    translate ([-10,0,0]) { //the other circular end
     cylinder (d=10,h=1,center=true);
    }
} //End of "union", the rest is taking bits away!

//Remove bits

    //The switch cut-out
    cube ([9,4.2,1.2],center=true);

    //The switch mounting holes
    translate ([9.5,0,0]) {
     cylinder (d=2.2,h=1.1,center=true);
    }
    translate ([-9.5,0,0]) {
     cylinder (d=2.2,h=1.1,center=true);
    }

    //Angled cut-off on shrouds
    translate([6,-6,1]) rotate ([0,-60,0])cube([10,12,10]);

    //The text on the switch to indicate On/Off.
    
    //Draw the "I"
    rotate(a=[0,0,90]) { //Turn thro' 90 deg
     translate ([0,13.5,0]) { //Move towards the end
        linear_extrude(height = 1) { 
        text("I", font = "Arial Rounded MT Bold:style=bold", size = 2,halign = "center", valign = "center");
      }
     }
    }
    
    //Draw the "O"
    rotate(a=[0,0,90]) {
     translate ([0,-13.5,0]) { //One end
      linear_extrude(height = 1) {    
       text("0", font = "Arial Rounded MT Bold:style=bold", size = 2, halign = "center", valign = "center");
      }
     }
    }
}